@@ -23,16 +23,24 @@ except ImportError as err:
 
 try:
     from .victor import Victor
-except ZeroDivisionError as err:
+except ImportError as err:
     warn(f'Victor (pipeline) unavailable —{err}.', category=ImportWarning)
 
 try:
     from .multivictor import MultiVictorPlacement
-except ZeroDivisionError as err:
+except ImportError as err:
     warn(f'Victor (pipeline) unavailable —{err}.', category=ImportWarning)
 
+
+try:
+    from .laboratory import Laboratory
+except ImportError as err:
+    warn(f'Laboratory unavailable —{err}.', category=ImportWarning)
+
 from .monster import Monster
+from .walton import Walton
 from molecular_rectifier import Rectifier
 from .m_rmsd import mRMSD
 from .mpro import MProVictor
 from .mpro import data as mpro_data
+from . import branding
